## 0.3.0 (May 26, 2013)

First-ever *official* release as a result of
[Neurosynth hackathon](http://hackathon.neurosynth.org)

- **Infrastructure**
  - Enabled travis-ci.org and coveralls.io
- **Code**
  - Everything what is done by now:
    - loading of Datasets
	- analysis and generation of statistical maps (as could now be seen on
	  [beta.neurosynth.org](http://beta.neurosynth.org)
- **Tests**
  - Formalized and increased tests coverage (currently at 66%)
  - [Testkraut](https://github.com/neurodebian/testkraut)

API is still a subject to change.
